--*****************************************************************************
--* File: lua/modules/ui/game/multifunction.lua
--* Author: Chris Blackwell
--* Summary: UI for the multifunction display
--*
--* Copyright  2005 Gas Powered Games, Inc.  All rights reserved.
--*****************************************************************************

local UIUtil = import('/lua/modules/ui/uiutil.lua')
local LayoutHelpers = import('/lua/modules/maui/layouthelpers.lua')
local Group = import('/lua/modules/maui/group.lua').Group
local Bitmap = import('/lua/modules/maui/bitmap.lua').Bitmap
local Checkbox = import('/lua/modules/maui/checkbox.lua').Checkbox
local Button = import('/lua/modules/maui/button.lua').Button
local Grid = import('/lua/modules/maui/grid.lua').Grid
local Text = import('/lua/modules/maui/text.lua').Text
local GameCommon = import('/lua/modules/ui/game/gamecommon.lua')
local Tooltip = import('/lua/modules/ui/game/tooltip.lua')
local econ = import("/lua/modules/ui/game/economy.lua")
local Prefs = import('/lua/modules/ui/prefs.lua')

local worldView = import('/lua/modules/ui/game/borders.lua').GetMapGroup()

local minimap = Prefs.GetFromCurrentProfile('stratview') or false
local mouseoverDisplay = false
local needExpand = false

buttonData = {
    [1] = {
        btnName = 'military',
        label = 'mfd_military',
        button = false,
        clickBehavior = function(self, checked)
            RenderOverlayMilitary(checked)
        end
    },
    [2] = {
        btnName = 'intelligence',
        label = 'mfd_intel',
        button = false,
        clickBehavior = function(self, checked)
            RenderOverlayIntel(checked)
        end
    },
    [3] = {
        btnName = 'economy',
        label = 'mfd_economy',
        button = false,
        clickBehavior = function(self, checked)
            toggleEconDisplay(checked)
        end
    },
    [4] = {
        btnName = 'team-color',
        label = 'mfd_defense',
        button = false,
        clickBehavior = function(self, checked)
            TeamColorMode(checked)
        end
    },
    [5] = {
        btnName = 'control',
        label = 'mfd_strat_view',
        button = false,
        clickBehavior = function(self, checked)
            ToggleMinimap()
        end
    },
}

controls = {
    controlClusterGroup = false,
    group = false,
    miniMap = false,
    bg = false,
    glow = false,
    displayGroup = false,   
    infoText = false,
    minimapBtns = {},
}

local econDisplayState = 0
function toggleEconDisplay(state)
    RenderOverlayEconomy(state)
end

function SetLayout(layout)
    import(UIUtil.GetLayoutFilename('multifunction')).SetLayout(minimap)
end

function SetupMultifunctionControl(parent)
    controls.controlClusterGroup = parent
    SetLayout(UIUtil.currentLayout)
	import('/mods/unitcam/unitcam.lua').Init(controls.miniMap)
    return controls.group
end

function ToggleMilitary()
    if controls.minimapBtns[1] then
        controls.minimapBtns[1].button:ToggleCheck()
    else
        import('/lua/modules/ui/game/options.lua').ToggleMFD('mfd_military')
    end
end

function ToggleDefense()
    if controls.minimapBtns[4] then
        controls.minimapBtns[4].button:ToggleCheck()
    else
        import('/lua/modules/ui/game/options.lua').ToggleMFD('mfd_defense')
    end
end

function ToggleEconomy()
    if controls.minimapBtns[3] then
        controls.minimapBtns[3].button:OnClick()
    else
        import('/lua/modules/ui/game/options.lua').ToggleMFD('mfd_economy')
    end
end

function ToggleIntel()
    if controls.minimapBtns[2] then
        controls.minimapBtns[2].button:ToggleCheck()
    else
        import('/lua/modules/ui/game/options.lua').ToggleMFD('mfd_intel')
    end
end

function ToggleControl()
    if controls.minimapBtns[5] then
        controls.minimapBtns[5].button:ToggleCheck()
    end
end

function Expand()
    if needExpand then
        controls.displayGroup:Show()
        SetLayout(UIUtil.currentLayout)
        needExpand = false
    end
end

function Contract()
    if minimap then
        controls.displayGroup:Hide()
        SetLayout(UIUtil.currentLayout)
        needExpand = true
    else
        needExpand = false
    end    
end

function ToggleMinimap()
    # disable when in Screen Capture mode
    if import('/lua/modules/ui/game/gamemain.lua').gameUIHidden then
        return
    end

    minimap = not minimap
    if minimap then
        controls.displayGroup:Show()
        SetLayout(UIUtil.currentLayout)
    else
        controls.displayGroup:Hide()
        SetLayout(UIUtil.currentLayout)
    end
    Prefs.SetToCurrentProfile('stratview', minimap)
end

function DisableMiniMap()
    if controls.displayGroup then
        minimap = false
        controls.displayGroup:Hide()
        SetLayout(UIUtil.currentLayout)
        Prefs.SetToCurrentProfile('stratview', minimap)
    end
end
